<?xml version="1.0" encoding="UTF-8"?>
<gui name="kmahjongg"
     version="7"
     xmlns="http://www.kde.org/standards/kxmlgui/1.0"
     xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
     xsi:schemaLocation="http://www.kde.org/standards/kxmlgui/1.0
                         http://www.kde.org/standards/kxmlgui/1.0/kxmlgui.xsd">

<MenuBar>
  <Menu name="game"><text>&amp;Game</text>
    <Action name="game_new_numeric" append="new_merge"/>
    <Action name="game_board_editor"/>
  </Menu>
  <Menu name="move"><text>&amp;Move</text>
    <Action name="move_shuffle"/>
  </Menu>
  <Menu name="view"><text>&amp;View</text>
    <Action name="view_anglecw"/>
    <Action name="view_angleccw"/>
  </Menu>
</MenuBar>

<ToolBar name="mainToolBar" noMerge="1"><text>Main Toolbar</text>
  <Action name="game_new"/>
  <Action name="game_load"/>
  <Action name="game_save"/>
  <Action name="move_undo"/>
  <Action name="move_redo"/>
  <Action name="game_pause"/>
  <Action name="fullscreen"/>
  <Action name="move_hint"/>
</ToolBar>

<State name="gameplay_state">
  <enable>
    <Action name="game_new"/>
    <Action name="game_new_numeric"/>
    <Action name="game_load"/>
    <Action name="game_save"/>
    <Action name="game_highscores"/>
    <Action name="move_hint"/>
    <Action name="game_pause"/>
    <Action name="move_demo"/>
    <Action name="view_angle"/>
  </enable>
</State>

<State name="demo_state">
  <enable>
    <Action name="move_demo"/>
  </enable>
  <disable>
    <Action name="game_new"/>
    <Action name="game_new_numeric"/>
    <Action name="game_load"/>
    <Action name="game_save"/>
    <Action name="game_highscores"/>
    <Action name="move_hint"/>
    <Action name="game_pause"/>
    <Action name="move_undo"/>
    <Action name="move_redo"/>
    <Action name="view_angle"/>
  </disable>
</State>

<State name="paused_state">
  <enable>
    <Action name="game_pause"/>
  </enable>
  <disable>
    <Action name="game_new"/>
    <Action name="game_new_numeric"/>
    <Action name="game_load"/>
    <Action name="game_save"/>
    <Action name="game_highscores"/>
    <Action name="move_hint"/>
    <Action name="move_undo"/>
    <Action name="move_redo"/>
    <Action name="move_demo"/>
    <Action name="view_angle"/>
  </disable>
</State>

<State name="finished_state">
    <disable>
        <Action name="move_undo"/>
        <Action name="move_redo"/>
        <Action name="move_demo"/>
        <Action name="move_hint"/>
        <Action name="game_save"/>
        <Action name="game_pause"/>
        <Action name="game_load"/>
        <Action name="view_angle"/>
    </disable>
    <enable>
        <Action name="game_new"/>
        <Action name="game_new_numeric"/>
        <Action name="game_highscores"/>
    </enable>
</State>

<State name="stuck_state">
    <disable>
        <Action name="move_redo"/>
        <Action name="move_demo"/>
        <Action name="move_hint"/>
         <Action name="game_pause"/>
   </disable>
    <enable>
        <Action name="view_angle"/>
        <Action name="game_save"/>
        <Action name="game_load"/>
        <Action name="move_undo"/>
        <Action name="game_new"/>
        <Action name="game_new_numeric"/>
        <Action name="game_highscores"/>
    </enable>
</State>
</gui>
